0.2.2 (2020-08-10)
------------------

- Escape strings from Jira that would be interpreted by GitHub
  as user mentions. [#26]

0.2.1 (2020-06-25)
------------------

- Documentation fixes

0.2.0 (2020-06-25)
------------------

- Introduce configuration file
- Major breaking changes to IssueSync class
- Remove GithubQuery and JiraQuery classes

0.1.0 (2019-07-19)
------------------

- Initial release
